dispose static method
void
dispose()
Dispose of resources.
Call this when the app is being disposed (rarely needed).
Implementation
static void dispose() {
_instance?.dispose();
_instance = null;
}
Dispose of resources.
Call this when the app is being disposed (rarely needed).
static void dispose() {
_instance?.dispose();
_instance = null;
}