AutoUpdaterGetxService class

GetX-based auto-updater service.

This adapter wraps AutoUpdaterCore and provides reactive state management via GetX observables. It also integrates with GetX navigation for dialogs.

Usage:

// Register the service
Get.put(AutoUpdaterGetxService(config: myConfig), permanent: true);

// Use in your widgets
final updater = Get.find<AutoUpdaterGetxService>();
Obx(() => updater.isDownloading.value ? ProgressIndicator() : Container())
Inheritance
  • Object
  • GetLifeCycle
  • DisposableInterface
  • GetxService
  • AutoUpdaterGetxService

Constructors

AutoUpdaterGetxService({required AutoUpdaterConfig config, AutoUpdaterUICallbacks? uiCallbacks})

Properties

config AutoUpdaterConfig
Access to the underlying configuration
no setter
currentVersion CurrentVersionInfo?
Current app version info
no setter
deviceArchitecture String?
Device architecture (Android only)
no setter
downloadProgress → RxDouble
Reactive state: download progress (0.0 to 1.0)
final
downloadStatus → RxString
Reactive state: download status message
final
hashCode int
The hash code for this object.
no setterinherited
initialized bool
Checks whether the controller has already been initialized.
no setterinherited
isCheckingForUpdate → RxBool
Reactive state: whether currently checking for updates
final
isClosed bool
Checks whether the controller has already been closed.
no setterinherited
isDownloading → RxBool
Reactive state: whether currently downloading
final
lastCheckResult → Rx<UpdateCheckResult?>
Reactive state: last update check result
final
onDelete → InternalFinalCallback<void>
Internal callback that starts the cycle of this controller.
finalinherited
onStart → InternalFinalCallback<void>
Called at the exact moment the widget is allocated in memory. It uses an internal "callable" type, to avoid any @overrides in subclases. This method should be internal and is required to define the lifetime cycle of the subclass.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
uiCallbacks AutoUpdaterUICallbacks?
UI customization callbacks
final

Methods

$configureLifeCycle() → void
inherited
cancelDownload() → void
Cancel an ongoing download
checkForUpdate({bool silent = true}) Future<UpdateCheckResult>
Check for updates.
cleanupDownloads() Future<void>
Clean up downloaded APK files
downloadAndInstall(VersionInfo versionInfo) Future<void>
Start the download and installation flow for a version.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onClose() → void
Called before onDelete method. onClose might be used to dispose resources used by the controller. Like closing events, or streams before the controller is destroyed. Or dispose objects that can potentially create some memory leaks, like TextEditingControllers, AnimationControllers. Might be useful as well to persist some data on disk.
override
onInit() → void
Called immediately after the widget is allocated in memory. You might use this to initialize something for the controller.
override
onReady() → void
Called 1 frame after onInit(). It is the perfect place to enter navigation events, like snackbar, dialogs, or a new route, or async request.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited