DownloadProgress class

Download progress information

Constructors

DownloadProgress({required int downloadedBytes, required int totalBytes, required double progress, required String status})
const

Properties

downloadedBytes int
final
formattedDownloaded String
no setter
formattedProgress String
no setter
formattedTotal String
no setter
hashCode int
The hash code for this object.
no setterinherited
progress double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String
final
totalBytes int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

formatBytes(int bytes) String
Format bytes to human-readable string (e.g., "1.5 MB")