DownloadProgressStyle class

Style configuration for DownloadProgressWidget

Constructors

DownloadProgressStyle({TextStyle? statusTextStyle, TextStyle? percentageTextStyle, TextStyle? bytesTextStyle, double progressBarHeight = 6.0, Color? progressBarColor, Color? progressBarBackgroundColor, double spacing = 16.0, String cancelText = 'Cancel'})
const

Properties

bytesTextStyle TextStyle?
final
cancelText String
final
hashCode int
The hash code for this object.
no setterinherited
percentageTextStyle TextStyle?
final
progressBarBackgroundColor Color?
final
progressBarColor Color?
final
progressBarHeight double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spacing double
final
statusTextStyle TextStyle?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited