VersionCheckButtonStyle class

Style configuration for VersionCheckButton

Constructors

VersionCheckButtonStyle({EdgeInsets padding = const EdgeInsets.all(16), BoxDecoration? decoration, double borderRadius = 8.0, bool showIcon = true, IconData icon = Icons.info_outline, Color? iconColor, double iconSize = 24, Color? loadingColor, String title = 'Version', TextStyle? titleStyle, TextStyle? versionStyle, String hintText = 'Tap to check for updates', String checkingText = 'Checking...', TextStyle? hintStyle, Color? chevronColor})
const

Properties

borderRadius double
final
checkingText String
final
chevronColor Color?
final
decoration BoxDecoration?
final
hashCode int
The hash code for this object.
no setterinherited
hintStyle TextStyle?
final
hintText String
final
icon IconData
final
iconColor Color?
final
iconSize double
final
loadingColor Color?
final
padding EdgeInsets
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showIcon bool
final
title String
final
titleStyle TextStyle?
final
versionStyle TextStyle?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited