VersionInfo class

Parsed version information from the server

Constructors

VersionInfo({required String version, required int build, required String apkUrl, required String displayVersion, String? releaseNotes, String? minVersion, bool isRequired = false})
const
VersionInfo.fromJson(Map<String, dynamic> json, VersionResponseFields fields)
factory
VersionInfo.fromReleaseHub(Map<String, dynamic> json, String baseUrl)
Parse ReleaseHub response format
factory

Properties

apkUrl String
final
build int
final
displayVersion String
final
hashCode int
The hash code for this object.
no setterinherited
isRequired bool
final
minVersion String?
final
releaseNotes String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
version String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited