AutoUpdaterCore class
Core auto-updater service (framework-agnostic).
This class handles all the update logic without any UI framework dependencies. Use this directly or wrap it with a framework-specific adapter (e.g., GetX).
Constructors
- AutoUpdaterCore({required AutoUpdaterConfig config})
Properties
- config → AutoUpdaterConfig
-
final
- currentVersion → CurrentVersionInfo?
-
Current app version info (available after initialization)
no setter
- deviceArchitecture → String?
-
The detected device architecture (Android only)
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isCheckingForUpdate → bool
-
Whether currently checking for updates
no setter
- isDownloading → bool
-
Whether currently downloading an update
no setter
- isInitialized → bool
-
Whether the service has been initialized
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
cancelDownload(
) → void - Cancel an ongoing download
-
checkForUpdate(
) → Future< UpdateCheckResult> - Check for available updates.
-
cleanupDownloads(
) → Future< void> - Clean up downloaded APK files
-
dispose(
) → void - Dispose of resources
-
downloadApk(
String apkUrl, String version, {void onProgress(DownloadProgress)?}) → Future< DownloadResult> - Download an APK file.
-
getDebugInfo(
) → String - Get debug info string for troubleshooting
-
initialize(
) → Future< void> - Initialize the service. Must be called before using other methods.
-
installApk(
String filePath) → Future< InstallResult> - Install a downloaded APK file.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
openAppSettings(
) → Future< bool> - Open app settings for manual permission configuration
-
requestInstallPermissions(
{Future< bool> onPermissionDialogRequired()?}) → Future<bool> - Request necessary permissions for installing APKs on Android.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited