AutoUpdaterDefaultUI class
Pre-built UI handlers using Flutter's built-in dialogs and snackbars.
Usage:
final updater = AutoUpdaterStandalone(
config: myConfig,
ui: AutoUpdaterDefaultUI.create(
primaryColor: Colors.blue,
strings: AutoUpdaterStrings(
updateAvailable: 'Aktualizácia dostupná',
download: 'Stiahnuť',
),
),
);
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
create(
{Color primaryColor = Colors.blue, AutoUpdaterStrings strings = const AutoUpdaterStrings(), GlobalKey< ScaffoldMessengerState> ? scaffoldMessengerKey, }) → AutoUpdaterStandaloneUI - Creates a default UI configuration using Flutter's built-in widgets.