UpdateBannerStyle class
Style configuration for UpdateAvailableBanner
Constructors
- UpdateBannerStyle({Color? backgroundColor, double elevation = 4.0, EdgeInsets padding = const EdgeInsets.symmetric(horizontal: 16, vertical: 12), bool showIcon = true, IconData icon = Icons.system_update, Color? iconColor, double iconSize = 28, String title = 'Update Available', TextStyle? titleStyle, TextStyle? messageStyle, String messageBuilder(VersionInfo)?, String updateButtonText = 'UPDATE', Color? buttonColor, Color? dismissButtonColor})
-
const
Properties
- backgroundColor → Color?
-
final
-
final
- dismissButtonColor → Color?
-
final
- elevation → double
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → IconData
-
final
- iconColor → Color?
-
final
- iconSize → double
-
final
- messageBuilder → String Function(VersionInfo)?
-
final
- messageStyle → TextStyle?
-
final
- padding → EdgeInsets
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showIcon → bool
-
final
- title → String
-
final
- titleStyle → TextStyle?
-
final
- updateButtonText → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited